JasonWoof Got questions, comments, patches, etc.? Contact Jason Woofenden
renamed untiled into floating, keeping tiled instead of tiling (afaik tiled sounds...
[dwm.git] / dwm.h
diff --git a/dwm.h b/dwm.h
index 9e04a81..d795c84 100644 (file)
--- a/dwm.h
+++ b/dwm.h
@@ -41,23 +41,6 @@ enum { WMProtocols, WMDelete, WMState, WMLast };     /* default atoms */
 enum { CurNormal, CurResize, CurMove, CurLast };       /* cursor */
 enum { ColBorder, ColFG, ColBG, ColLast };             /* color */
 
-typedef struct {
-       int ascent;
-       int descent;
-       int height;
-       XFontSet set;
-       XFontStruct *xfont;
-} Fnt;
-
-typedef struct {
-       int x, y, w, h;
-       unsigned long norm[ColLast];
-       unsigned long sel[ColLast];
-       Drawable drawable;
-       Fnt font;
-       GC gc;
-} DC; /* draw context */
-
 typedef struct Client Client;
 struct Client {
        char name[256];
@@ -67,7 +50,7 @@ struct Client {
        int minax, minay, maxax, maxay;
        long flags; 
        unsigned int border;
-       Bool isbanned, isfixed, ismax, isversatile;
+       Bool isbanned, isfixed, ismax, isfloating;
        Bool *tags;
        Client *next;
        Client *prev;
@@ -76,6 +59,21 @@ struct Client {
 };
 
 typedef struct {
+       int x, y, w, h;
+       unsigned long norm[ColLast];
+       unsigned long sel[ColLast];
+       Drawable drawable;
+       GC gc;
+       struct {
+               int ascent;
+               int descent;
+               int height;
+               XFontSet set;
+               XFontStruct *xfont;
+       } font;
+} DC; /* draw context */
+
+typedef struct {
        const char *symbol;
        void (*arrange)(void);
 } Layout;
@@ -105,7 +103,7 @@ extern void killclient(const char *arg);            /* kill c nicely */
 extern void manage(Window w, XWindowAttributes *wa);   /* manage new client */
 extern void resize(Client *c, int x, int y,
                int w, int h, Bool sizehints);  /* resize with given coordinates c*/
-extern void toggleversatile(const char *arg);  /* toggles focused client between versatile/and non-versatile state */
+extern void togglefloating(const char *arg);   /* toggles focused client between floating/tiled state */
 extern void updatesizehints(Client *c);                /* update the size hint variables of c */
 extern void updatetitle(Client *c);            /* update the name of c */
 extern void unmanage(Client *c);               /* destroy c */
@@ -119,16 +117,15 @@ extern unsigned int textw(const char *text);      /* return the width of text in px*/
 extern void grabkeys(void);                    /* grab all keys defined in config.h */
 
 /* layout.c */
-extern void focusnext(const char *arg);                /* focuses next visible client, arg is ignored  */
-extern void focusprev(const char *arg);                /* focuses previous visible client, arg is ignored */
+extern void floating(void);                    /* arranges all windows floating */
+extern void focusclient(const char *arg);      /* focuses next(1)/previous(-1) visible client */
 extern void incmasterw(const char *arg);       /* increments the master width with arg's index value */
 extern void incnmaster(const char *arg);       /* increments nmaster with arg's index value */
 extern void initlayouts(void);                 /* initialize layout array */
 extern Client *nexttiled(Client *c);           /* returns tiled successor of c */
 extern void restack(void);                     /* restores z layers of all clients */
 extern void setlayout(const char *arg);                /* sets layout, -1 toggles */
-extern void togglemax(const char *arg);                /* toggles maximization of versatile client */
-extern void versatile(void);                   /* arranges all windows versatile */
+extern void togglemax(const char *arg);                /* toggles maximization of floating client */
 extern void zoom(const char *arg);             /* zooms the focused client to master area, arg is ignored */
 
 /* main.c */